==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGroupByRowTemplateContextEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRowTemplateContextDescriptionMetadata } from "./WebGroupByRowTemplateContextDescriptionMetadata";
import { WebGroupByRowTemplateContextEventArgsDescription } from "./WebGroupByRowTemplateContextEventArgsDescription";
/**
 * @hidden
 */
var WebGroupByRowTemplateContextEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupByRowTemplateContextEventArgsDescriptionMetadata, _super);
    function WebGroupByRowTemplateContextEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.b = function (a) {
        if (WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a == null) {
            WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByRowTemplateContextEventArgsDescriptionMetadata.c(WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a);
        WebGroupByRowTemplateContextDescriptionMetadata.d(a);
    };
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByRowTemplateContextEventArgs");
        a.item("Detail", "ExportedType:WebGroupByRowTemplateContext");
    };
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.d = function (a) {
        WebGroupByRowTemplateContextEventArgsDescriptionMetadata.b(a);
        a.aa("WebGroupByRowTemplateContextEventArgs", function () { return new WebGroupByRowTemplateContextEventArgsDescription(); });
        a.z("WebGroupByRowTemplateContextEventArgs", WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a);
    };
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.$t = markType(WebGroupByRowTemplateContextEventArgsDescriptionMetadata, 'WebGroupByRowTemplateContextEventArgsDescriptionMetadata');
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a = null;
    return WebGroupByRowTemplateContextEventArgsDescriptionMetadata;
}(Base));
export { WebGroupByRowTemplateContextEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGroupByRowTemplateContextEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRowTemplateContextDescriptionMetadata } from "./WebGroupByRowTemplateContextDescriptionMetadata";
import { WebGroupByRowTemplateContextEventArgsDescription } from "./WebGroupByRowTemplateContextEventArgsDescription";
/**
 * @hidden
 */
var WebGroupByRowTemplateContextEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupByRowTemplateContextEventArgsDescriptionMetadata, _super);
    function WebGroupByRowTemplateContextEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.b = function (a) {
        if (WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a == null) {
            WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGroupByRowTemplateContextEventArgsDescriptionMetadata.c(WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a);
        WebGroupByRowTemplateContextDescriptionMetadata.d(a);
    };
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GroupByRowTemplateContextEventArgs");
        a.item("Detail", "ExportedType:WebGroupByRowTemplateContext");
    };
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.d = function (a) {
        WebGroupByRowTemplateContextEventArgsDescriptionMetadata.b(a);
        a.ac("WebGroupByRowTemplateContextEventArgs", function () { return new WebGroupByRowTemplateContextEventArgsDescription(); });
        a.ab("WebGroupByRowTemplateContextEventArgs", WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a);
    };
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.$t = markType(WebGroupByRowTemplateContextEventArgsDescriptionMetadata, 'WebGroupByRowTemplateContextEventArgsDescriptionMetadata');
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a = null;
    return WebGroupByRowTemplateContextEventArgsDescriptionMetadata;
}(Base));
export { WebGroupByRowTemplateContextEventArgsDescriptionMetadata };
